/**
 * NOTE: THIS IS A GENERATED FILE. PLEASE CONSULT THE ORIGINAL IDL FILE
 * FOR THE FULL DOCUMENTION AND LICENSE.
 *
 * @see <a href="http://lxr.mozilla.org/mozilla/search?string=interface+nsIDOMHTMLHeadEleme">
 **/

package org.mozilla.xpcom;

public interface nsIDOMHTMLHeadElement extends nsIDOMHTMLElement
{
  public static final String NS_IDOMHTMLHEADELEMENT_IID =
    "{a6cf9087-15b3-11d2-932e-00805f8add32}";

  public String getProfile();

  public void setProfile(String arg1);

}
